package com.gyee.frame.controller.admin;

import com.github.pagehelper.PageInfo;
import com.gyee.frame.common.base.BaseController;
import com.gyee.frame.common.domain.AjaxResult;
import com.gyee.frame.common.log.Log;
import com.gyee.frame.model.auto.*;
import com.gyee.frame.model.custom.RoleVo;
import com.gyee.frame.model.custom.TableSplitResult;
import com.gyee.frame.model.custom.Tablepar;
import com.gyee.frame.model.custom.TitleVo;
import com.gyee.frame.service.SysDepartmentService;
import com.gyee.frame.service.SysPositionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 用户Controller
 * @ClassName: UserVueController
 * @author gyee
 * @date 2019-11-20 22:35
 */
@Api(value = "用户数据")
@Controller
@RequestMapping("/UserVueController")
public class UserVueController extends BaseController{
	
	private String prefix = "admin/uservue";
	//部门
	@Resource
	private SysDepartmentService departmentService;
	//岗位
	@Resource
	private SysPositionService positionService;
	
	/**
	 * 展示跳转页面
	 * @param model
	 * @return
	 * @author gyee
	 * @Date 2019年11月11日 下午4:14:34
	 */
	@ApiOperation(value = "分页跳转", notes = "分页跳转")
	@GetMapping("/view")
	@RequiresPermissions("system:uservue:view")
    public String view(ModelMap model)
    {	
		String str="VUE用户";
		setTitle(model, new TitleVo("列表", str+"管理", true,"欢迎进入"+str+"页面", true, false));
        return prefix + "/list";
    }
	
	
	/**
	 * list集合
	 * @param tablepar
	 * @param searchText
	 * @return
	 * @author gyee
	 * @Date 2019年11月11日 下午4:14:40
	 */
	//@Log(title = "分页查询", action = "1")
	@ApiOperation(value = "分页查询", notes = "分页查询")
	@PostMapping("/list")
	@RequiresPermissions("system:uservue:list")
	@ResponseBody
	public Object list(Tablepar tablepar,String searchText){
		PageInfo<TvueUser> page=vueUserService.list(tablepar,searchText) ; 
		TableSplitResult<TvueUser> result=new TableSplitResult<TvueUser>(page.getPageNum(), page.getTotal(), page.getList()); 
		return  result;
	}
	/**
	 * 新增跳转
	 * @param modelMap
	 * @return
	 * @author gyee
	 * @Date 2019年11月11日 下午4:14:51
	 */
	@ApiOperation(value = "新增跳转", notes = "新增跳转")
    @GetMapping("/add")
    public String add(ModelMap modelMap)
    {
    	//添加角色列表
		List<TsysRole> tsysRoleList=sysRoleService.queryList();
		//部门列表
		List<SysDepartment> departments=departmentService.selectByExample(new SysDepartmentExample());
		//岗位列表
		List<SysPosition> sysPositions=positionService.selectByExample(new SysPositionExample());
		//角色
		modelMap.put("tsysRoleList",tsysRoleList);
		//部门
		modelMap.put("departmentsList",departments);
		//岗位
		modelMap.put("sysPositionsList",sysPositions);
        return prefix + "/add";
    }
	/**
	 * 新增保存
	 * @param uservue
	 * @param model
	 * @param roles
	 * @return
	 * @author gyee
	 * @Date 2019年11月11日 下午4:14:57
	 */
    @Log(title = "用户新增", action = "111")
    @ApiOperation(value = "新增", notes = "新增")
	@PostMapping("/add")
	@RequiresPermissions("system:uservue:add")
	@ResponseBody
	public AjaxResult add(TvueUser uservue,Model model,@RequestParam(value="roles", required = false)List<String> roles){
		int b=vueUserService.insertUserVueRoles(uservue,roles);
		if(b>0){
			return success();
		}else{
			return error();
		}
	}
	
	/**
	 * 删除用户
	 * @param ids
	 * @return
	 */
    //@Log(title = "删除用户", action = "1")
  	@ApiOperation(value = "删除", notes = "删除")
	@PostMapping("/remove")
	@RequiresPermissions("system:uservue:remove")
	@ResponseBody
	public AjaxResult remove(String ids){
		int b=vueUserService.deleteByPrimaryKey(ids);
		if(b>0){
			return success();
		}else{
			return error();
		}
	}
	
	/**
	 * 检查用户
	 * @param tsysUserVue
	 * @return
	 */
	@ApiOperation(value = "检查Name唯一", notes = "检查Name唯一")
	@PostMapping("/checkLoginNameUnique")
	@ResponseBody
	public int checkLoginNameUnique(TvueUser tsysUserVue){
		int b=vueUserService.checkLoginNameUnique(tsysUserVue);
		if(b>0){
			return 1;
		}else{
			return 0;
		}
	}
	
	
	/**
	 * 修改用户跳转
	 * @param id
	 * @param mmap
	 * @return
	 */
	@ApiOperation(value = "修改跳转", notes = "修改跳转")
	@GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
		//查询所有角色
		List<RoleVo> roleVos=vueUserService.getUserVueIsRole(id);
		//岗位列表
		List<SysPosition> sysPositions=positionService.selectByExample(new SysPositionExample());
		mmap.put("roleVos",roleVos);
        mmap.put("TvueUser", vueUserService.selectByPrimaryKey(id));
        //岗位
        mmap.put("sysPositionsList",sysPositions);
        return prefix + "/edit";
    }
	
	/**
     * 修改保存用户
     */
	//@Log(title = "修改保存用户", action = "1")
    @ApiOperation(value = "修改保存用户", notes = "修改保存用户")
    @RequiresPermissions("system:uservue:edit")
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TvueUser tsysUserVue,@RequestParam(value="roles", required = false)List<String> roles)
    {
        return toAjax(vueUserService.updateUserVueRoles(tsysUserVue,roles));
    }

    
    
    /**
	 * 修改用户密码跳转
	 * @param id
	 * @param mmap
	 * @return
	 */
    //@Log(title = "修改用户密码", action = "1")
    @ApiOperation(value = "修改用户密码跳转", notes = "修改用户密码跳转")
	@GetMapping("/editPwd/{id}")
    public String editPwd(@PathVariable("id") String id, ModelMap mmap)
    {
        mmap.put("TvueUser", vueUserService.selectByPrimaryKey(id));
        return prefix + "/editPwd";
    }
	/**
     * 修改保存用户
     */
    //@Log(title = "修改用户密码", action = "1")
    @ApiOperation(value = "修改用户密码", notes = "修改用户密码")
    @RequiresPermissions("system:uservue:editPwd")
    @PostMapping("/editPwd")
    @ResponseBody
    public AjaxResult editPwdSave(TvueUser tsysUserVue)
    {
        return toAjax(vueUserService.updateUserVuePassword(tsysUserVue));
    }

	
}
